/****************************************************************************
** Meta object code from reading C++ file 'metadata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeplasma-addons-6.6.90/applets/weather/weatherdata/metadata.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'metadata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8MetaDataE_t {};
} // unnamed namespace

template <> constexpr inline auto MetaData::qt_create_metaobjectdata<qt_meta_tag_ZN8MetaDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MetaData",
        "credit",
        "creditURL",
        "QVariant",
        "temperatureUnit",
        "windSpeedUnit",
        "visibilityUnit",
        "pressureUnit",
        "humidityUnit",
        "rainfallUnit",
        "snowfallUnit",
        "precipUnit"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'credit'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'creditURL'
        QtMocHelpers::PropertyData<QVariant>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'temperatureUnit'
        QtMocHelpers::PropertyData<QVariant>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'windSpeedUnit'
        QtMocHelpers::PropertyData<QVariant>(5, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'visibilityUnit'
        QtMocHelpers::PropertyData<QVariant>(6, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pressureUnit'
        QtMocHelpers::PropertyData<QVariant>(7, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'humidityUnit'
        QtMocHelpers::PropertyData<QVariant>(8, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'rainfallUnit'
        QtMocHelpers::PropertyData<QVariant>(9, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'snowfallUnit'
        QtMocHelpers::PropertyData<QVariant>(10, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'precipUnit'
        QtMocHelpers::PropertyData<QVariant>(11, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MetaData, qt_meta_tag_ZN8MetaDataE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MetaData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8MetaDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8MetaDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8MetaDataE_t>.metaTypes,
    nullptr
} };

void MetaData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<MetaData *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->credit(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->creditURL(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->temperatureUnit(); break;
        case 3: *reinterpret_cast<QVariant*>(_v) = _t->windSpeedUnit(); break;
        case 4: *reinterpret_cast<QVariant*>(_v) = _t->visibilityUnit(); break;
        case 5: *reinterpret_cast<QVariant*>(_v) = _t->pressureUnit(); break;
        case 6: *reinterpret_cast<QVariant*>(_v) = _t->humidityUnit(); break;
        case 7: *reinterpret_cast<QVariant*>(_v) = _t->rainfallUnit(); break;
        case 8: *reinterpret_cast<QVariant*>(_v) = _t->snowfallUnit(); break;
        case 9: *reinterpret_cast<QVariant*>(_v) = _t->precipUnit(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
