// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "dwd_debug.h"

 namespace WEATHER { namespace ION {
Q_LOGGING_CATEGORY(DWD, "org.kde.weather.ion.dwd", QtInfoMsg)
} } 
